Learn R Programming

alfr (version 1.2.1)

alfr: alfr: A package for connecting with Alfresco

Description

The alfr package provides a way to connect to Alfresco and interact with the contents of the repository.

Session

  • alf_session - connection session to an Alfresco repository

  • alf_session.is_valid - determine whether the session connection to an Alfresco repository is still valid

  • alf_session.invalidate - invalidates a session so it can no longer use used to connect to an Alfresco repository

Nodes

Arguments