Learn R Programming

alfr (version 1.1.0)

alfr: alfr: A package for connecting with Alfresco

Description

The alfr package provides a way to connect to Alfresco and interact with the contents of the repository.

Arguments